==> vtk-6.3.0-5-armv7h.pkg.tar.xz: vtk/vtkChartXY.java <==
// java wrapper for vtkChartXY object
//

package vtk;
import vtk.*;

public class vtkChartXY extends vtkChart
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Update_2();
  public void Update()
    { Update_2(); }

  private native boolean Paint_3(vtkContext2D id0);
  public boolean Paint(vtkContext2D id0)
    { return Paint_3(id0); }

  private native long AddPlot_4(int id0);
  public vtkPlot AddPlot(int id0) {
    long temp = AddPlot_4(id0);

    if (temp == 0) return null;
    return (vtkPlot)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int AddPlot_5(vtkPlot id0);
  public int AddPlot(vtkPlot id0)
    { return AddPlot_5(id0); }

  private native boolean RemovePlot_6(int id0);
  public boolean RemovePlot(int id0)
    { return RemovePlot_6(id0); }

  private native void ClearPlots_7();
  public void ClearPlots()
    { ClearPlots_7(); }

  private native long GetPlot_8(int id0);
  public vtkPlot GetPlot(int id0) {
    long temp = GetPlot_8(id0);

    if (temp == 0) return null;
    return (vtkPlot)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int GetPlotIndex_9(vtkPlot id0);
  public int GetPlotIndex(vtkPlot id0)
    { return GetPlotIndex_9(id0); }

  private native int RaisePlot_10(vtkPlot id0);
  public int RaisePlot(vtkPlot id0)
    { return RaisePlot_10(id0); }

  private native int StackPlotAbove_11(vtkPlot id0,vtkPlot id1);
  public int StackPlotAbove(vtkPlot id0,vtkPlot id1)
    { return StackPlotAbove_11(id0,id1); }

  private native int LowerPlot_12(vtkPlot id0);
  public int LowerPlot(vtkPlot id0)
    { return LowerPlot_12(id0); }

  private native int StackPlotUnder_13(vtkPlot id0,vtkPlot id1);
  public int StackPlotUnder(vtkPlot id0,vtkPlot id1)
    { return StackPlotUnder_13(id0,id1); }

  private native int GetNumberOfPlots_14();
  public int GetNumberOfPlots()
    { return GetNumberOfPlots_14(); }

  private native int GetPlotCorner_15(vtkPlot id0);
  public int GetPlotCorner(vtkPlot id0)
    { return GetPlotCorner_15(id0); }

  private native void SetPlotCorner_16(vtkPlot id0,int id1);
  public void SetPlotCorner(vtkPlot id0,int id1)
    { SetPlotCorner_16(id0,id1); }

  private native long GetAxis_17(int id0);
  public vtkAxis GetAxis(int id0) {
    long temp = GetAxis_17(id0);

    if (temp == 0) return null;
    return (vtkAxis)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetShowLegend_18(boolean id0);
  public void SetShowLegend(boolean id0)
    { SetShowLegend_18(id0); }

  private native long GetLegend_19();
  public vtkChartLegend GetLegend() {
    long temp = GetLegend_19();

    if (temp == 0) return null;
    return (vtkChartLegend)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetTooltip_20(vtkTooltipItem id0);
  public void SetTooltip(vtkTooltipItem id0)
    { SetTooltip_20(id0); }

  private native long GetTooltip_21();
  public vtkTooltipItem GetTooltip() {
    long temp = GetTooltip_21();

    if (temp == 0) return null;
    return (vtkTooltipItem)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int GetNumberOfAxes_22();
  public int GetNumberOfAxes()
    { return GetNumberOfAxes_22(); }

  private native void RecalculateBounds_23();
  public void RecalculateBounds()
    { RecalculateBounds_23(); }

  private native void SetSelectionMethod_24(int id0);
  public void SetSelectionMethod(int id0)
    { SetSelectionMethod_24(id0); }

  private native void SetDrawAxesAtOrigin_25(boolean id0);
  public void SetDrawAxesAtOrigin(boolean id0)
    { SetDrawAxesAtOrigin_25(id0); }

  private native boolean GetDrawAxesAtOrigin_26();
  public boolean GetDrawAxesAtOrigin()
    { return GetDrawAxesAtOrigin_26(); }

  private native void DrawAxesAtOriginOn_27();
  public void DrawAxesAtOriginOn()
    { DrawAxesAtOriginOn_27(); }

  private native void DrawAxesAtOriginOff_28();
  public void DrawAxesAtOriginOff()
    { DrawAxesAtOriginOff_28(); }

  private native void SetAutoAxes_29(boolean id0);
  public void SetAutoAxes(boolean id0)
    { SetAutoAxes_29(id0); }

  private native boolean GetAutoAxes_30();
  public boolean GetAutoAxes()
    { return GetAutoAxes_30(); }

  private native void AutoAxesOn_31();
  public void AutoAxesOn()
    { AutoAxesOn_31(); }

  private native void AutoAxesOff_32();
  public void AutoAxesOff()
    { AutoAxesOff_32(); }

  private native void SetHiddenAxisBorder_33(int id0);
  public void SetHiddenAxisBorder(int id0)
    { SetHiddenAxisBorder_33(id0); }

  private native int GetHiddenAxisBorder_34();
  public int GetHiddenAxisBorder()
    { return GetHiddenAxisBorder_34(); }

  private native void SetForceAxesToBounds_35(boolean id0);
  public void SetForceAxesToBounds(boolean id0)
    { SetForceAxesToBounds_35(id0); }

  private native boolean GetForceAxesToBounds_36();
  public boolean GetForceAxesToBounds()
    { return GetForceAxesToBounds_36(); }

  private native void ForceAxesToBoundsOn_37();
  public void ForceAxesToBoundsOn()
    { ForceAxesToBoundsOn_37(); }

  private native void ForceAxesToBoundsOff_38();
  public void ForceAxesToBoundsOff()
    { ForceAxesToBoundsOff_38(); }

  private native void SetBarWidthFraction_39(double id0);
  public void SetBarWidthFraction(double id0)
    { SetBarWidthFraction_39(id0); }

  private native double GetBarWidthFraction_40();
  public double GetBarWidthFraction()
    { return GetBarWidthFraction_40(); }

  public vtkChartXY() { super(); }

  public vtkChartXY(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkChartXY.java <==
// java wrapper for vtkChartXY object
//

package vtk;
import vtk.*;

public class vtkChartXY extends vtkChart
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Update_2();
  public void Update()
    { Update_2(); }

  private native boolean Paint_3(vtkContext2D id0);
  public boolean Paint(vtkContext2D id0)
    { return Paint_3(id0); }

  private native long AddPlot_4(int id0);
  public vtkPlot AddPlot(int id0) {
    long temp = AddPlot_4(id0);

    if (temp == 0) return null;
    return (vtkPlot)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int AddPlot_5(vtkPlot id0);
  public int AddPlot(vtkPlot id0)
    { return AddPlot_5(id0); }

  private native boolean RemovePlot_6(int id0);
  public boolean RemovePlot(int id0)
    { return RemovePlot_6(id0); }

  private native void ClearPlots_7();
  public void ClearPlots()
    { ClearPlots_7(); }

  private native long GetPlot_8(int id0);
  public vtkPlot GetPlot(int id0) {
    long temp = GetPlot_8(id0);

    if (temp == 0) return null;
    return (vtkPlot)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetPlotIndex_9(vtkPlot id0);
  public int GetPlotIndex(vtkPlot id0)
    { return GetPlotIndex_9(id0); }

  private native int RaisePlot_10(vtkPlot id0);
  public int RaisePlot(vtkPlot id0)
    { return RaisePlot_10(id0); }

  private native int StackPlotAbove_11(vtkPlot id0,vtkPlot id1);
  public int StackPlotAbove(vtkPlot id0,vtkPlot id1)
    { return StackPlotAbove_11(id0,id1); }

  private native int LowerPlot_12(vtkPlot id0);
  public int LowerPlot(vtkPlot id0)
    { return LowerPlot_12(id0); }

  private native int StackPlotUnder_13(vtkPlot id0,vtkPlot id1);
  public int StackPlotUnder(vtkPlot id0,vtkPlot id1)
    { return StackPlotUnder_13(id0,id1); }

  private native int GetNumberOfPlots_14();
  public int GetNumberOfPlots()
    { return GetNumberOfPlots_14(); }

  private native int GetPlotCorner_15(vtkPlot id0);
  public int GetPlotCorner(vtkPlot id0)
    { return GetPlotCorner_15(id0); }

  private native void SetPlotCorner_16(vtkPlot id0,int id1);
  public void SetPlotCorner(vtkPlot id0,int id1)
    { SetPlotCorner_16(id0,id1); }

  private native long GetAxis_17(int id0);
  public vtkAxis GetAxis(int id0) {
    long temp = GetAxis_17(id0);

    if (temp == 0) return null;
    return (vtkAxis)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetShowLegend_18(boolean id0);
  public void SetShowLegend(boolean id0)
    { SetShowLegend_18(id0); }

  private native long GetLegend_19();
  public vtkChartLegend GetLegend() {
    long temp = GetLegend_19();

    if (temp == 0) return null;
    return (vtkChartLegend)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTooltip_20(vtkTooltipItem id0);
  public void SetTooltip(vtkTooltipItem id0)
    { SetTooltip_20(id0); }

  private native long GetTooltip_21();
  public vtkTooltipItem GetTooltip() {
    long temp = GetTooltip_21();

    if (temp == 0) return null;
    return (vtkTooltipItem)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetNumberOfAxes_22();
  public int GetNumberOfAxes()
    { return GetNumberOfAxes_22(); }

  private native void RecalculateBounds_23();
  public void RecalculateBounds()
    { RecalculateBounds_23(); }

  private native void SetSelectionMethod_24(int id0);
  public void SetSelectionMethod(int id0)
    { SetSelectionMethod_24(id0); }

  private native void SetDrawAxesAtOrigin_25(boolean id0);
  public void SetDrawAxesAtOrigin(boolean id0)
    { SetDrawAxesAtOrigin_25(id0); }

  private native boolean GetDrawAxesAtOrigin_26();
  public boolean GetDrawAxesAtOrigin()
    { return GetDrawAxesAtOrigin_26(); }

  private native void DrawAxesAtOriginOn_27();
  public void DrawAxesAtOriginOn()
    { DrawAxesAtOriginOn_27(); }

  private native void DrawAxesAtOriginOff_28();
  public void DrawAxesAtOriginOff()
    { DrawAxesAtOriginOff_28(); }

  private native void SetAutoAxes_29(boolean id0);
  public void SetAutoAxes(boolean id0)
    { SetAutoAxes_29(id0); }

  private native boolean GetAutoAxes_30();
  public boolean GetAutoAxes()
    { return GetAutoAxes_30(); }

  private native void AutoAxesOn_31();
  public void AutoAxesOn()
    { AutoAxesOn_31(); }

  private native void AutoAxesOff_32();
  public void AutoAxesOff()
    { AutoAxesOff_32(); }

  private native void SetHiddenAxisBorder_33(int id0);
  public void SetHiddenAxisBorder(int id0)
    { SetHiddenAxisBorder_33(id0); }

  private native int GetHiddenAxisBorder_34();
  public int GetHiddenAxisBorder()
    { return GetHiddenAxisBorder_34(); }

  private native void SetForceAxesToBounds_35(boolean id0);
  public void SetForceAxesToBounds(boolean id0)
    { SetForceAxesToBounds_35(id0); }

  private native boolean GetForceAxesToBounds_36();
  public boolean GetForceAxesToBounds()
    { return GetForceAxesToBounds_36(); }

  private native void ForceAxesToBoundsOn_37();
  public void ForceAxesToBoundsOn()
    { ForceAxesToBoundsOn_37(); }

  private native void ForceAxesToBoundsOff_38();
  public void ForceAxesToBoundsOff()
    { ForceAxesToBoundsOff_38(); }

  private native void SetBarWidthFraction_39(double id0);
  public void SetBarWidthFraction(double id0)
    { SetBarWidthFraction_39(id0); }

  private native double GetBarWidthFraction_40();
  public double GetBarWidthFraction()
    { return GetBarWidthFraction_40(); }

  private native void SetZoomWithMouseWheel_41(boolean id0);
  public void SetZoomWithMouseWheel(boolean id0)
    { SetZoomWithMouseWheel_41(id0); }

  private native boolean GetZoomWithMouseWheel_42();
  public boolean GetZoomWithMouseWheel()
    { return GetZoomWithMouseWheel_42(); }

  private native void ZoomWithMouseWheelOn_43();
  public void ZoomWithMouseWheelOn()
    { ZoomWithMouseWheelOn_43(); }

  private native void ZoomWithMouseWheelOff_44();
  public void ZoomWithMouseWheelOff()
    { ZoomWithMouseWheelOff_44(); }

  private native void SetAdjustLowerBoundForLogPlot_45(boolean id0);
  public void SetAdjustLowerBoundForLogPlot(boolean id0)
    { SetAdjustLowerBoundForLogPlot_45(id0); }

  private native boolean GetAdjustLowerBoundForLogPlot_46();
  public boolean GetAdjustLowerBoundForLogPlot()
    { return GetAdjustLowerBoundForLogPlot_46(); }

  private native void AdjustLowerBoundForLogPlotOn_47();
  public void AdjustLowerBoundForLogPlotOn()
    { AdjustLowerBoundForLogPlotOn_47(); }

  private native void AdjustLowerBoundForLogPlotOff_48();
  public void AdjustLowerBoundForLogPlotOff()
    { AdjustLowerBoundForLogPlotOff_48(); }

  public vtkChartXY() { super(); }

  public vtkChartXY(long id) { super(id); }
  public native long   VTKInit();

}
